angular.module('starter.controllers', [])


.controller('DashCtrl', function($scope, Dash, $ionicPlatform, $ionicLoading, $ionicScrollDelegate) {
  //, "moz", "MS", "o", ""
  var pfx = ["webkit"];
  var refreshScrollTimeout;

  getColor = function(status_type){
    if (status_type == "0"){
      return "custom-icon-ok";
    }
    if (status_type == "1"){
      return "custom-icon-warning";
    }
    if (status_type >= "2"){
      return "custom-icon-not-ok";
    }
    return "custom-icon-black";
  };

  processMessage = function(message){
    if (message.trim() == "Ok"){
      return "Sem problemas a reportar.";
    } else {
      return message;
    }
  }

  parseInformation = function(data){
    var lines_status = [];

    lines_status.push({
      id: 0,
      tag: 'amarela',
      name: 'Amarela',
      status: processMessage(data.amarela),
      status_type: getColor(data.tipo_msg_am)
    })

    lines_status.push({
      id: 0,
      tag: 'azul',
      name: 'Azul',
      status: processMessage(data.azul),
      status_type: getColor(data.tipo_msg_az)
    })

    lines_status.push({
      id: 0,
      tag: 'verde',
      name: 'Verde',
      status: processMessage(data.verde),
      status_type: getColor(data.tipo_msg_vd)
    })

    lines_status.push({
      id: 0,
      tag: 'vermelha',
      name: 'Vermelha',
      status: processMessage(data.vermelha),
      status_type: getColor(data.tipo_msg_vm)
    })
    return lines_status;
  };

  getInformation = function(){
    $ionicLoading.show({
      content: 'Loading',
      animation: 'fade-in',
      showBackdrop: false,
      maxWidth: 200,
      showDelay: 0
    });

    Dash.all().then(function(resp) {
      $scope.lines_status = parseInformation(resp.data);
      $ionicLoading.hide();
    }, function(err) {
      var lines_status = [];
      lines_status.push({
        id: 0,
        name: 'Ups...',
        status: "Alguma coisa correu mal! Por favor faça refresh e tente novamente.",
        status_type: "",
        color: '#444'
      })

      $scope.lines_status = lines_status;
      $ionicLoading.hide();
      console.error('ERR', err);
    });
  };

  getInformation();

  $scope.doRefresh = function() {

    Dash.all().then(function(resp) {
      $scope.lines_status = parseInformation(resp.data);
      $scope.$broadcast('scroll.refreshComplete');
    }, function(err) {
      var lines_status = [];
      lines_status.push({
        id: 0,
        name: 'Ups...',
        status: "Alguma coisa correu mal! Por favor faça refresh e tente noamente.",
        status_type: getColor("")
      })

      $scope.lines_status = lines_status;
      $scope.$broadcast('scroll.refreshComplete');

      console.error('ERR', err);
    })
  };

  function isElementInViewport (el) {

    var rect = el.getBoundingClientRect();

    return (
        rect.top >= 0 &&
        rect.left >= 0 &&
        rect.bottom <= document.getElementsByClassName("scroll")[0].getBoundingClientRect().height+2 &&
        rect.right <= document.getElementsByClassName("scroll")[0].getBoundingClientRect().width
    );
}

  transitionEnded = function(elementToExpand){
    removePrefixedEvent(elementToExpand.srcElement, "TransitionEnd", transitionEnded);
    $ionicScrollDelegate.resize();
    clearTimeout(refreshScrollTimeout);

    if(!isElementInViewport(elementToExpand.srcElement)) {
      $ionicScrollDelegate.scrollTo(0, elementToExpand.srcElement.offsetTop, true);
    }
  }

  prefixedEvent = function (element, type, callback) {
    for (var p = 0; p < pfx.length; p++) {
      if (!pfx[p]) type = type.toLowerCase();
      element.addEventListener(pfx[p]+type, callback, false);
    }
  }

  removePrefixedEvent = function (element, type, callback) {
    for (var p = 0; p < pfx.length; p++) {
      if (!pfx[p]) type = type.toLowerCase();
      element.removeEventListener(pfx[p]+type, callback, false);
    }
  }

  refreshScroll = function() {
    $ionicScrollDelegate.resize();
    refreshScrollTimeout = setTimeout(refreshScroll, 100);
  }

  $scope.expandLine = function(){

    var activeDivs = document.getElementsByClassName("active");

    for (var i = activeDivs.length - 1; i >= 0; i--) {
      if(activeDivs[i].id != this.line_status.tag){
        var classesName = activeDivs[i].className;
        classesName = classesName.replace(' active', '');
        activeDivs[i].removeAttribute("style");
        activeDivs[i].className = classesName;
      }
    };

    var elementToExpand = document.getElementById(this.line_status.tag);

    if (!~elementToExpand.className.indexOf('active')){
      var currentHeight = elementToExpand.clientHeight;
      var textHeight = elementToExpand.getElementsByClassName("custom-text")[0].clientHeight;
      elementToExpand.style.height = currentHeight + textHeight + "px";
      elementToExpand.className = elementToExpand.className + " active";
    } else {
      var classesName = elementToExpand.className;
      classesName = classesName.replace(' active', '');
      elementToExpand.className = classesName;
      elementToExpand.removeAttribute("style");
    }
    clearTimeout(refreshScrollTimeout);
    refreshScrollTimeout = setTimeout(refreshScroll, 1);
    prefixedEvent(elementToExpand, "TransitionEnd", transitionEnded);
  };

  $ionicPlatform.on('resume', function(){
    getInformation();
  });

})

.controller('AboutCtrl', function($window, $scope) {
  $scope.sendEmail = function(){
    if(window.plugins && window.plugins.emailComposer) {
        window.plugins.emailComposer.showEmailComposerWithCallback(function(result) {
            console.log("Response -> " + result);
        },
        "Linhas do Metro", // Subject
        "",                      // Body
        ["hello@waveweb2.com"],    // To
        null,                    // CC
        null,                    // BCC
        false,                   // isHTML
        null,                    // Attachments
        null);                   // Attachment Data
    }
  }
})

.controller('MapCtrl', function($ionicGesture, $scope, $ionicScrollDelegate) {
  $scope.$on('$ionicView.loaded', function(){
    $ionicScrollDelegate.zoomTo(0.5, false);
    var gesture_element = angular.element(document.querySelector('#map'));
    $ionicGesture.on("doubletap", function(e){
      if($ionicScrollDelegate.getScrollView().__zoomLevel == 1){
        $ionicScrollDelegate.zoomTo(0.5, true,e.gesture.center.pageX,e.gesture.center.pageY);
      } else {
        $ionicScrollDelegate.zoomTo(1, true,e.gesture.center.pageX,e.gesture.center.pageY);
      }
    }, gesture_element);
  });

});
